@@ -1,10 +1,10 @@
 from releasemanager.config import KlassBuilder
 
 class AnonymousAuth(object):
-    def authenticate(*args, **kwargs):
+    def authenticate(self, *args, **kwargs):
         return True
     
-    def authorize(*args, **kwargs):
+    def authorize(self, *args, **kwargs):
         return True
 
 
@@ -23,9 +23,9 @@ class PluginBase(object):
     def __init__(self, config):
         self._config = config
         
-    def authenticate(*args, **kwargs):
+    def authenticate(self, *args, **kwargs):
         raise NotImplementedError("Abstract, implement in derived class")
     
-    def authorize(*args, **kwargs):
+    def authorize(self, *args, **kwargs):
         raise NotImplementedError("Abstract, implement in derived class")
 
