@@ -128,5 +128,6 @@ class BuildBehavior(object):
         try:
             self.fullBuild(branch=branch, revision=revision, url=url, tag=tag, trunk=trunk, components=components, unique=unique)
             return True
-        except:
+        except Exception, e:
+            logging.info("Failed from full build with exception: %s" % str(e))
             return False
\ No newline at end of file
