@@ -22,7 +22,7 @@ def main():
     from twisted.web import server, resource
     """run server"""
     root = resource.Resource()
-    rs = ReleaseManagerService(name, configPath)
+    rs = ReleaseManagerService(name, configPath, configStyle='py')
     root.putChild('RPC2', rs)
     site = server.Site(root)
     port = int(str(rs._config.listen_port))
