@@ -1,4 +1,4 @@
-import os, sys
+import os
 from releasemanager import utils
 from target import InstallBehavior
 
