@@ -1,6 +1,4 @@
-import os, sys
-from releasemanager.config import ConfigLoader, DEFAULT_CONFIG_PATH
-from releasemanager import utils
+from releasemanager.config import ConfigLoader
 from releasemanager.logger import ReleaseLogger
 from target import NamedTarget
 
@@ -20,7 +18,6 @@ class ReleaseInstaller(object):
         # we intentionally wipe out any old named targets here,
         # so that when a config reloads, only the new ones are there
         self.environments = {}
-        named_targets = []
         for nt in self._config.named_targets.target:
             configPath = getattr(nt, 'config_path', None)
             if not configPath:
@@ -38,6 +35,10 @@ class ReleaseInstaller(object):
         self._loadConfig()
         self.logger.log("Loaded release installer config %s from %s" % (self._configName, self._configPath))
         self._buildNamedTargets()
+    
+    def reload(self):
+        """just for more intuitive use, same as load"""
+        return self.load()
 
 
     def install(self, env, name, resource, version):
