@@ -74,6 +74,8 @@ class ReleaseManager(object):
         self._build_registrations()
         self._loadProjects()
         
+    def reload(self):
+        return self.load()
     
     def getTransaction(self, request_data):
         return request_data.get('__relman_transaction__', '')
@@ -109,12 +111,19 @@ class ReleaseManager(object):
     def check_registration(self, reg, kill=False):
         s = socket.socket()
         host, port = reg.location.split(":")
-        connected = True
+        connected = False
         try:
             s.connect((host, int(port)))
+            connected = True
         except:
             connected = False
         if connected:
+            # idea is that if we just proved it's connected
+            # update the registered_at time so it'll be 
+            # good for a bit longer
+            reg.registered_at = datetime.datetime.now()
+            reg.save()
+            reg.flush()
             return True
         # if not connected, check if we should just wipe it
         # we're going to return false regardless, since it just said
@@ -184,6 +193,27 @@ class ReleaseManager(object):
         hist.save()
         hist.flush()
         hist.expunge()
+    
+    def respond_for_action(self, type, credentials, data):
+        location = "%s:%s" % (data['host'], data['port'])
+        payload = data.get('payload')
+        # just to make sure that "get transaction" works correctly
+        payload['__relman_transaction__'] = payload['transaction']
+        if not payload:
+            self.logger.log("Failure to find payload in response for action! request from %s, data like: %s" % (location, data))  
+            return  
+        trans_id = self.getTransaction(payload)
+        self.save_transaction(trans_id, payload["status"])
+        hist_id = self.make_history(credentials, payload)
+        status = False
+        if payload["status"].endswith("COMPLETED"):
+            status = True
+        hist = self.persistence.History.get_by(id=hist_id)
+        hist.success = status
+        hist.message = "Response for action: %s from location: %s" % (payload["action"], location)
+        hist.save()
+        hist.flush()
+        hist.expunge()
 
     def register(self, type, data):
         allowed_type = False
@@ -301,7 +331,7 @@ class ReleaseManager(object):
         self.save_transaction(trans_id, 'BUILD_STARTED')
         trans_status = "BUILD_FAILED"
         if status:
-            trans_status = "BUILD_COMPLETED"
+            trans_status = "BUILD_IN_PROGRESS"
             self.save_transaction(trans_id, trans_status)
             return resource
         self.save_transaction(trans_id, trans_status)
@@ -362,7 +392,7 @@ class ReleaseManager(object):
         trans_id = self.getTransaction(request_data)
         self.save_transaction(trans_id, 'INSTALL_STARTED')            
         try:
-            trans_status = "INSTALL_COMPLETED"
+            trans_status = "INSTALL_IN_PROGRESS"
             for target in proj.targets:
                 release_daemons = endpoints[target]['release_daemons']
                 data = endpoints[target]['resource']
