@@ -76,7 +76,23 @@ class SvcWorkerBase(SvcBase):
                 s.callRemote('register', '%s' % self.prefix, registration)
             except Exception, e:
                 logging.info("%s: Unable to register with ReleaseManager %s, error: %s" % (self._logentry, url, str(e)))
-        
+
+
+    def respond_for_action(self, credentials, payload):
+        for h in self._config.release_managers.host:
+            url = "http://%s:%s/RPC2" % (str(h.name), str(h.port))
+            try:
+                s = xmlrpc.Proxy(url)
+                response = dict(
+                    host = socket.gethostname(),
+                    port = str(self._config.listen_port),
+                    payload = payload
+                    )
+                logging.debug("payload looks like this: %s" % payload)
+                s.callRemote('respond_for_action', '%s' % self.prefix, credentials, response)
+            except Exception, e:
+                logging.info("%s: Unable to respond for action to ReleaseManager %s, error: %s" % (self._logentry, url, str(e)))
+
     
     def xmlrpc_new_config(self, credentials, request_data):
         newconfig = request_data.get('newconfig')
