@@ -20,6 +20,7 @@ class BuildHostService(SvcWorkerBase):
         tag = request_data.get('tag', '')
         trunk = request_data.get('trunk', False)
         unique_base = request_data.get('__relman_unique_request_base__', '')
+        transaction = request_data.get('__relman_transaction__', '')
         if not self.auth.authenticate(credentials):
             logging.info("%s: Not Authenticated for username: %s" % (self._logentry, credentials.get('username')))
             return (False, '')
@@ -34,9 +35,17 @@ class BuildHostService(SvcWorkerBase):
             logging.info("%s: Not Authorized for build action %s for username: %s" % (self._logentry, auth_role, credentials.get('username')))
             return (False, '')
         status, resource = self.actor.build(name, branch=branch, revision=revision, url=url, tag=tag, trunk=trunk, unique=unique_base)
+        # the lines below are for creating mock resourcs for test
+        #from releasemanager.tests.mock.resource import MockResource
+        #status = True
+        #resource = MockResource('test').data
         if not isinstance(resource, xmlrpc.Binary):
             resource = xmlrpc.Binary(resource)
         logging.info("%s: Status of build for %s is %s" % (self._logentry, name, status))
+        report_status = "BUILD_FAILED"
+        if status:
+            report_status = "BUILD_COMPLETED"
+        self.respond_for_action(credentials, dict(action="build", status=report_status, transaction=transaction))
         return (status, resource)
         
 
