@@ -32,6 +32,12 @@ class ReleaseManagerService(SvcBase):
         logging.info("%s: Requested report of registration" % (self._logentry))
         return self.actor.report_registrations()
 
+    
+    def xmlrpc_respond_for_action(self, type, credentials, data):
+        """update the history table correctly when the action actually finishes"""
+        logging.info("%s: Updated response for requested action" % (self._logentry))
+        return self.actor.respond_for_action(type, credentials, data)
+
 
 if __name__ == "__main__":
     from optparse import OptionParser
