@@ -1,4 +1,4 @@
-import os, sys
+import os
 import tempfile
 from releasemanager import utils
 
