@@ -11,10 +11,10 @@ valid_targets = {
     "builder" : BuilderCreator, 
     "manager" : ManagerCreator,
 }
-builtin_auth_plugins = ["simpleauth"]
+builtin_auth_plugins = ["simpleauth", "admin"]
 
 def main():
-    usage = "usage: %prog [generate] [installer|builder|manager] [name] [options]"
+    usage = "usage: %prog [generate] [installer|builder|manager|webconsole] [name] [options]"
     parser = OptionParser(usage)
     parser.add_option("-a", "--auth-plugin", dest="auth", help="use a builtin auth plugin")
     (options, args) = parser.parse_args()
@@ -27,16 +27,25 @@ def main():
     auth = options.auth
     if command not in valid_commands:
         parser.error("Command %s is not a valid command" % command)
+        
+    plugin_creator = PluginCreator
+
+    if target == "webconsole":
+        from releasemanager.web.console.ctl.generate import WebConsoleCreator, WebPluginCreator
+        plugin_creator = WebPluginCreator
+        valid_targets['webconsole'] = WebConsoleCreator
+        
     if target not in valid_targets:
         parser.error("Target %s is not a valid target" % target)
-    
+
+   
     base_path = os.getcwd()
     gen = valid_targets[target](base_path, name)
     gen.generate()
     
     # now for plugins
     if auth:
-        pl = PluginCreator("auth", auth, install_base=os.path.join(base_path, name))
+        pl = plugin_creator("auth", auth, install_base=os.path.join(base_path, name))
         pl.install()
 
 
